@@ -55,14 +55,21 @@
 #' Err(fit.sub, type="loglike")
 #' 
 #' @author Martin Vincent
+#' @importFrom utils packageVersion
+#' @importFrom methods is
 #' @export
-#' @useDynLib msgl .registration=TRUE
+#' @useDynLib msgl, .registration=TRUE
 msgl.subsampling <- function(x, classes, sampleWeights = rep(1/length(classes), length(classes)), grouping = NULL, groupWeights = NULL, parameterWeights = NULL, alpha = 0.5, standardize = TRUE,
 		lambda, training, test, intercept = TRUE, sparse.data = is(x, "sparseMatrix"), collapse = FALSE, max.threads = 2L, algorithm.config = msgl.standard.config) {
 	
 	# Get call
 	cl <- match.call()
 	
+	#Check dimensions 
+	if(nrow(x) != length(classes)) {
+		stop("the number of rows in x must match the length of classes")
+	}
+	
 	# Default values
 	if(is.null(grouping)) {
 		covariateGrouping <- factor(1:ncol(x))
@@ -85,18 +92,33 @@ msgl.subsampling <- function(x, classes, sampleWeights = rep(1/length(classes),
 	
 	# Standardize
 	if(standardize) {
-		x <- scale(x, if(sparse.data) FALSE else TRUE, TRUE)
-		x.scale <- attr(x, "scaled:scale")
-		x.center <- if(sparse.data) rep(0, length(x.scale)) else attr(x, "scaled:center")
+		
+		if(sparse.data) {
+			x.scale <- sqrt(colMeans(x*x) - colMeans(x)^2)
+			x.center <- rep(0, length(x.scale))
+			x <- x%*%Diagonal(x=1/x.scale)
+		} else {
+			x <- scale(x, if(sparse.data) FALSE else TRUE, TRUE)
+			x.scale <- attr(x, "scaled:scale")
+			x.center <- if(sparse.data) rep(0, length(x.scale)) else attr(x, "scaled:center")
+		}
+	}
+		
+	if(intercept) {
+		intercept.value = 1
+	} else {
+		intercept.value = 0
+	}
+	# add intercept
+	if(is.null(colnames(x))) {
+		x <- cBind(rep(intercept.value, nrow(x)), x)
+	} else {
+		x <- cBind(Intercept = rep(intercept.value, nrow(x)), x)
 	}
 	
-	if(intercept) {
-		# add intercept
-		x <- cBind(Intercept = rep(1, nrow(x)), x)
-		groupWeights <- c(0, groupWeights)
-		parameterWeights <- cbind(rep(0, length(levels(classes))), parameterWeights)
-		covariateGrouping <- factor(c("Intercept", as.character(covariateGrouping)), levels = c("Intercept", levels(covariateGrouping)))
-	}
+	groupWeights <- c(0, groupWeights)
+	parameterWeights <- cbind(rep(0, length(levels(classes))), parameterWeights)
+	covariateGrouping <- factor(c("Intercept", as.character(covariateGrouping)), levels = c("Intercept", levels(covariateGrouping)))
 	
 	# create data
 	data <- create.sgldata(x, y = NULL, sampleWeights, classes, sparseX = sparse.data)
@@ -106,11 +128,11 @@ msgl.subsampling <- function(x, classes, sampleWeights = rep(1/length(classes),
 		if(algorithm.config$verbose) {
 			
 			cat(paste("Running msgl subsampling with ", length(training)," subsamples (sparse design matrix)\n\n", sep=""))
-			print(data.frame('Samples: ' = length(sampleWeights), 
-							'Features: ' = data$n.covariate, 
-							'Classes: ' = length(levels(classes)), 
-							'Groups: ' = length(unique(covariateGrouping)), 
-							'Parameters: ' = length(parameterWeights),
+			print(data.frame('Samples: ' = print_with_metric_prefix(length(sampleWeights)), 
+							'Features: ' = print_with_metric_prefix(data$n.covariate), 
+							'Classes: ' = print_with_metric_prefix(length(levels(classes))), 
+							'Groups: ' = print_with_metric_prefix(length(unique(covariateGrouping))), 
+							'Parameters: ' = print_with_metric_prefix(length(parameterWeights)),
 							check.names = FALSE), 
 					row.names = FALSE, digits = 2, right = TRUE)
 			cat("\n")
@@ -123,11 +145,11 @@ msgl.subsampling <- function(x, classes, sampleWeights = rep(1/length(classes),
 			if(algorithm.config$verbose) {
 				
 				cat(paste("Running msgl subsampling with ", length(training)," subsamples (dense design matrix)\n\n", sep=""))
-				print(data.frame('Samples: ' = length(sampleWeights), 
-								'Features: ' = data$n.covariate, 
-								'Classes: ' = length(levels(classes)), 
-								'Groups: ' = length(unique(covariateGrouping)), 
-								'Parameters: ' = length(parameterWeights),
+				print(data.frame('Samples: ' = print_with_metric_prefix(length(sampleWeights)), 
+								'Features: ' = print_with_metric_prefix(data$n.covariate), 
+								'Classes: ' = print_with_metric_prefix(length(levels(classes))), 
+								'Groups: ' = print_with_metric_prefix(length(unique(covariateGrouping))), 
+								'Parameters: ' = print_with_metric_prefix(length(parameterWeights)),
 								check.names = FALSE), 
 						row.names = FALSE, digits = 2, right = TRUE)
 				cat("\n")
@@ -157,7 +179,6 @@ msgl.subsampling <- function(x, classes, sampleWeights = rep(1/length(classes),
 
 	# Various 
 	res$msgl_version <- packageVersion("msgl")
-	res$intercept <- intercept
 	res$call <- cl
 
 	class(res) <- "msgl"
