@@ -42,6 +42,7 @@
 
 //Sgl optimizer
 #include <sgl.h>
+#include "pkg_c_config.h"
 
 /**********************************
  *
@@ -113,15 +114,6 @@ extern "C" {
 
 void R_init_msgl(DllInfo *info)
 {
-	// Print warnings
-#ifndef SGL_OPENMP_SUPP
-	Rf_warning("msgl does not support multithreading on this system");
-#endif
-
-#ifdef SGL_DEBUG
-	Rf_warning("Compiled with debugging on -- this may slow down the runtime of the sgl routines");
-#endif
-
-// Register the .Call routines.
+	// Register the .Call routines.
 	R_registerRoutines(info, NULL, sglCallMethods, NULL, NULL);
 }
