@@ -1,5 +1,8 @@
 library(msgl)
 
+# warnings = errors
+options(warn=2)
+
 ### Basic tests
 
 data(SimData)
@@ -10,7 +13,13 @@ set.seed(100L)
 
 lambda <- msgl.lambda.seq(x, classes, alpha = .5, d = 25L, lambda.min = 0.05, standardize = TRUE)
 
-fit.cv <- msgl.cv(x, classes, alpha = .5, lambda = lambda, standardize = TRUE, max.threads = 2L)
+if(sgl.c.config()$omp.supported) {
+	threads = 2L
+} else {
+	threads = 1L
+}
+
+fit.cv <- msgl.cv(x, classes, alpha = .5, lambda = lambda, standardize = TRUE, max.threads = threads)
 
 err.count <- colSums(fit.cv$classes != classes)
 
